/****************************************************************************
** Meta object code from reading C++ file 'kmagzoomview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmag-26.04.1/src/kmagzoomview.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmagzoomview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KMagZoomViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KMagZoomView::qt_create_metaobjectdata<qt_meta_tag_ZN12KMagZoomViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMagZoomView",
        "setZoom",
        "",
        "zoom",
        "setRotation",
        "rotation",
        "setColorMode",
        "mode",
        "grabFrame",
        "updateMouseView",
        "followMouse",
        "follow",
        "followBoth",
        "followFocus",
        "showSelRect",
        "show",
        "setSelRectPos",
        "QRect",
        "rect",
        "setRefreshRate",
        "fps",
        "showMouse",
        "type",
        "setFitToWindow",
        "fit",
        "fitToWindow",
        "focusChanged",
        "QAccessibleClient::AccessibleObject",
        "object"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(float)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 3 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setRotation'
        QtMocHelpers::SlotData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 },
        }}),
        // Slot 'setRotation'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setColorMode'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setColorMode'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'grabFrame'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateMouseView'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'followMouse'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'followMouse'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'followBoth'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'followBoth'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'followFocus'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'followFocus'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'showSelRect'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'showSelRect'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setSelRectPos'
        QtMocHelpers::SlotData<void(const QRect &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setRefreshRate'
        QtMocHelpers::SlotData<void(float)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Slot 'showMouse'
        QtMocHelpers::SlotData<bool(unsigned int)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::UInt, 22 },
        }}),
        // Slot 'setFitToWindow'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setFitToWindow'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'fitToWindow'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusChanged'
        QtMocHelpers::SlotData<void(const QAccessibleClient::AccessibleObject &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMagZoomView, qt_meta_tag_ZN12KMagZoomViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMagZoomView::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractScrollArea::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KMagZoomViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KMagZoomViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KMagZoomViewE_t>.metaTypes,
    nullptr
} };

void KMagZoomView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMagZoomView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 1: _t->setZoom(); break;
        case 2: _t->setRotation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->setRotation(); break;
        case 4: _t->setColorMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setColorMode(); break;
        case 6: _t->grabFrame(); break;
        case 7: _t->updateMouseView(); break;
        case 8: _t->followMouse((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->followMouse(); break;
        case 10: _t->followBoth((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->followBoth(); break;
        case 12: _t->followFocus((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->followFocus(); break;
        case 14: _t->showSelRect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->showSelRect(); break;
        case 16: _t->setSelRectPos((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 17: _t->setRefreshRate((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 18: { bool _r = _t->showMouse((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setFitToWindow((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setFitToWindow(); break;
        case 21: _t->fitToWindow(); break;
        case 22: _t->focusChanged((*reinterpret_cast<std::add_pointer_t<QAccessibleClient::AccessibleObject>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 22:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAccessibleClient::AccessibleObject >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KMagZoomView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMagZoomView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KMagZoomViewE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractScrollArea::qt_metacast(_clname);
}

int KMagZoomView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractScrollArea::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
