/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kmagui.rc
  0x0,0x0,0x2,0x4d,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xda,0xa,0x1d,0x12,0x0,0x6,0x56,0x43,0x1f,0x40,0x73,0x1e,
  0x73,0xb1,0xb,0x99,0x4c,0x76,0x40,0x5a,0xb3,0xa4,0x56,0x27,0x68,0xab,0xf0,0xe,
  0x75,0xb4,0x72,0x8c,0xf6,0x9f,0x24,0xb8,0x23,0x30,0x6,0x4,0x3d,0x0,0x39,0x0,
  0x37,0x0,0x91,0xdd,0xb0,0x85,0xa2,0xe6,0xfd,0x64,0xe3,0x8a,0x32,0xe4,0x9d,0xd1,
  0xa7,0x88,0xff,0x13,0x88,0x19,0xa,0xd,0xe1,0xdf,0x95,0xb2,0x86,0xb5,0xea,0x49,
  0x4c,0x43,0xb0,0x7c,0xe,0x1,0xa2,0x6,0x2d,0x24,0x58,0xfa,0x26,0xa6,0x31,0x48,
  0x63,0x22,0x59,0x24,0xd6,0xb7,0x62,0xd,0x89,0x65,0xb2,0x88,0x30,0x2,0x50,0xf0,
  0xa5,0x54,0x2b,0x6f,0x6b,0xb9,0x4e,0x1c,0xb9,0xba,0x3a,0x29,0x7b,0xbf,0x35,0x6f,
  0x27,0xff,0x3b,0xee,0x61,0xf4,0xed,0xa3,0x6f,0xb2,0xf4,0x34,0xab,0x32,0xa5,0x98,
  0xba,0xf9,0xb6,0x3a,0x4b,0x9f,0xad,0xfe,0x6d,0xa7,0x4,0xc4,0x2a,0x17,0xb7,0x6,
  0x10,0x3d,0xf,0x44,0xdf,0x85,0x41,0x2,0x4f,0x39,0xf3,0x27,0xd7,0xb0,0xd,0xf9,
  0xb1,0x7d,0x33,0xde,0x74,0x3a,0xfb,0x56,0x9d,0xcf,0xab,0xbb,0xd8,0x39,0xb6,0xe3,
  0x30,0xe5,0x13,0x70,0x6c,0x76,0x9d,0x21,0xce,0x4c,0xa7,0xca,0xf1,0xad,0xeb,0x7a,
  0xe8,0x7d,0xd5,0x3b,0x3d,0xc5,0xf5,0xbe,0xbc,0x3e,0xc6,0xa7,0x9e,0x74,0x1c,0x80,
  0xa8,0x6f,0xf5,0x40,0x80,0xa8,0x4d,0xca,0x7c,0x49,0xb5,0xad,0xf2,0x86,0xde,0x17,
  0xe,0x63,0x1c,0xd3,0x5b,0x35,0xe5,0x3f,0xf9,0x57,0x4e,0xa5,0x77,0x62,0xd8,0xd6,
  0x60,0xf0,0xc,0x6,0x1,0x8e,0xf,0x48,0x1f,0xf4,0x67,0xa5,0x77,0xb9,0xce,0xd2,
  0x5d,0x6f,0xcd,0x6f,0x8e,0x7e,0xfc,0xe9,0xd9,0x80,0x82,0xa0,0x31,0x9e,0x99,0x1a,
  0x11,0x9a,0xd6,0x28,0x74,0x40,0x44,0x20,0x88,0x29,0xa2,0xf2,0x96,0x28,0x96,0x5b,
  0x24,0x72,0xef,0xd7,0x1d,0x9b,0x1e,0x2a,0x90,0x79,0xc3,0x7c,0xa4,0xff,0xba,0x13,
  0x5a,0xf0,0x85,0x9a,0x76,0x68,0xf3,0x61,0x8d,0xaa,0xa1,0x8f,0x32,0x78,0xb,0xb6,
  0x63,0xf6,0x8,0x6b,0x5b,0x71,0x8a,0x24,0x27,0x87,0x11,0xf5,0x5e,0xdf,0x36,0x88,
  0x53,0x7a,0xe6,0xaf,0x2b,0xa9,0x1,0x3,0x4b,0x26,0xa9,0x10,0xcb,0x50,0x9e,0x44,
  0x9,0x92,0x24,0x41,0x8,0x24,0xf8,0x78,0x4,0x49,0x23,0xd8,0xd5,0x4b,0x24,0x3b,
  0x51,0xc4,0x4d,0xb8,0xd7,0x8,0xfe,0x62,0x36,0x96,0x58,0x85,0x96,0x75,0x38,0x39,
  0xbe,0xc0,0x1a,0x78,0x78,0x20,0x79,0xc8,0x97,0x73,0xa5,0xb6,0x94,0x4a,0x1b,0x3a,
  0x1c,0x50,0xf0,0x4b,0x6b,0xdb,0x27,0x6c,0xed,0xec,0x2f,0x8c,0x63,0xa3,0xb3,0xb4,
  0x57,0xee,0xc0,0x42,0x1a,0x99,0x68,0xee,0x78,0x1f,0xd9,0x3a,0xc,0xb2,0x57,0xdf,
  0x8,0x9a,0x34,0xd0,0xba,0xe1,0x37,0x43,0xe2,0xf6,0x8e,0xd2,0x2c,0x1c,0x85,0x90,
  0x31,0x6b,0x6b,0x74,0xd6,0xca,0x69,0x80,0xc3,0x41,0x58,0xf8,0xb9,0x7,0xa6,0x37,
  0x3b,0xaf,0xdc,0xd6,0x1d,0x6c,0xd6,0x9a,0x19,0x80,0x57,0x50,0xb7,0x89,0x73,0x56,
  0x75,0x7d,0xaf,0x8d,0xfc,0x27,0x85,0x48,0xfc,0xe,0x9f,0xaf,0xc7,0x70,0x92,0x2e,
  0x5c,0x18,0xae,0x5a,0xcb,0xb,0x3c,0x36,0x41,0x77,0x5c,0xf8,0x5c,0xd,0x62,0xeb,
  0xb8,0xc1,0x62,0x1d,0x12,0x84,0xb7,0xc2,0x38,0x80,0xb2,0x23,0x73,0xfb,0xba,0x58,
  0x32,0x9c,0xc0,0x66,0x3c,0xa3,0x53,0x89,0xed,0xeb,0xbb,0x6e,0xbe,0x5,0x8,0x77,
  0x65,0xda,0xc5,0x64,0x6f,0x88,0x25,0xba,0x38,0xad,0xd6,0x6,0x3a,0x3c,0xeb,0x74,
  0xd6,0x5c,0x1,0x54,0x61,0x50,0xaf,0x40,0x9a,0x80,0x59,0x5,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kmag
  0x0,0x4,
  0x0,0x7,0x23,0x77,
  0x0,0x6b,
  0x0,0x6d,0x0,0x61,0x0,0x67,
    // kmagui.rc
  0x0,0x9,
  0x7,0xeb,0x61,0xe3,
  0x0,0x6b,
  0x0,0x6d,0x0,0x61,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9d,0xfa,0x53,0xcc,0x28,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9d,0xfa,0x53,0xcc,0x28,
  // :/kxmlgui5/kmag
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9d,0xfa,0x53,0xcc,0x28,
  // :/kxmlgui5/kmag/kmagui.rc
  0x0,0x0,0x0,0x24,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9d,0xfa,0x53,0xcc,0x28,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kmag)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kmag)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kmag)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kmag)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kmag)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kmag)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
