/****************************************************************************
** Meta object code from reading C++ file 'kmag.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmag-26.04.1/src/kmag.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmag.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KmagAppE_t {};
} // unnamed namespace

template <> constexpr inline auto KmagApp::qt_create_metaobjectdata<qt_meta_tag_ZN7KmagAppE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KmagApp",
        "updateZoomIndex",
        "",
        "updateZoomValue",
        "updateRotationIndex",
        "updateRotationValue",
        "updateFPSIndex",
        "updateFPSValue",
        "updateColorIndex",
        "updateColorValue",
        "slotFileNewWindow",
        "slotFilePrint",
        "slotFileQuit",
        "copyToClipBoard",
        "slotToggleRefresh",
        "slotModeChanged",
        "slotModeWholeScreen",
        "slotModeSelWin",
        "zoomIn",
        "zoomOut",
        "saveZoomPixmap",
        "setZoomIndex",
        "index",
        "setRotationIndex",
        "setFPSIndex",
        "setColorIndex",
        "showMouseCursor",
        "show",
        "slotShowMenu",
        "slotToggleHideCursor",
        "slotStaysOnTop",
        "slotConfKeys",
        "slotNewToolbarConfig",
        "slotEditToolbars",
        "slotChangeZoomBoxIndex",
        "slotChangeRotationBoxIndex",
        "slotChangeFPSIndex",
        "slotChangeColorIndex"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateZoomIndex'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'updateZoomValue'
        QtMocHelpers::SignalData<void(float)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'updateRotationIndex'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'updateRotationValue'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'updateFPSIndex'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'updateFPSValue'
        QtMocHelpers::SignalData<void(float)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 2 },
        }}),
        // Signal 'updateColorIndex'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'updateColorValue'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotFileNewWindow'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFilePrint'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFileQuit'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'copyToClipBoard'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleRefresh'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotModeChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotModeWholeScreen'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotModeSelWin'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveZoomPixmap'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setZoomIndex'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setRotationIndex'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setFPSIndex'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setColorIndex'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'showMouseCursor'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'slotShowMenu'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotToggleHideCursor'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStaysOnTop'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotConfKeys'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewToolbarConfig'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditToolbars'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChangeZoomBoxIndex'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'slotChangeRotationBoxIndex'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'slotChangeFPSIndex'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'slotChangeColorIndex'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KmagApp, qt_meta_tag_ZN7KmagAppE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KmagApp::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KmagAppE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KmagAppE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KmagAppE_t>.metaTypes,
    nullptr
} };

void KmagApp::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KmagApp *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateZoomIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->updateZoomValue((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 2: _t->updateRotationIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->updateRotationValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->updateFPSIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->updateFPSValue((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->updateColorIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->updateColorValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->slotFileNewWindow(); break;
        case 9: _t->slotFilePrint(); break;
        case 10: _t->slotFileQuit(); break;
        case 11: _t->copyToClipBoard(); break;
        case 12: _t->slotToggleRefresh(); break;
        case 13: _t->slotModeChanged(); break;
        case 14: _t->slotModeWholeScreen(); break;
        case 15: _t->slotModeSelWin(); break;
        case 16: _t->zoomIn(); break;
        case 17: _t->zoomOut(); break;
        case 18: _t->saveZoomPixmap(); break;
        case 19: _t->setZoomIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->setRotationIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setFPSIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setColorIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->showMouseCursor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->slotShowMenu(); break;
        case 25: _t->slotToggleHideCursor(); break;
        case 26: _t->slotStaysOnTop(); break;
        case 27: _t->slotConfKeys(); break;
        case 28: _t->slotNewToolbarConfig(); break;
        case 29: _t->slotEditToolbars(); break;
        case 30: _t->slotChangeZoomBoxIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->slotChangeRotationBoxIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotChangeFPSIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->slotChangeColorIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(int )>(_a, &KmagApp::updateZoomIndex, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(float )>(_a, &KmagApp::updateZoomValue, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(int )>(_a, &KmagApp::updateRotationIndex, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(int )>(_a, &KmagApp::updateRotationValue, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(int )>(_a, &KmagApp::updateFPSIndex, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(float )>(_a, &KmagApp::updateFPSValue, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(int )>(_a, &KmagApp::updateColorIndex, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KmagApp::*)(int )>(_a, &KmagApp::updateColorValue, 7))
            return;
    }
}

const QMetaObject *KmagApp::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KmagApp::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KmagAppE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KmagApp::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 34)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 34;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 34)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 34;
    }
    return _id;
}

// SIGNAL 0
void KmagApp::updateZoomIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KmagApp::updateZoomValue(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KmagApp::updateRotationIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KmagApp::updateRotationValue(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KmagApp::updateFPSIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KmagApp::updateFPSValue(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KmagApp::updateColorIndex(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KmagApp::updateColorValue(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
